/****************************************************************************
** Meta object code from reading C++ file 'ksview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ksudoku-26.04.3/src/gui/views/ksview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7ksudoku6KsViewE_t {};
} // unnamed namespace

template <> constexpr inline auto ksudoku::KsView::qt_create_metaobjectdata<qt_meta_tag_ZN7ksudoku6KsViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ksudoku::KsView",
        "flagsChanged",
        "",
        "ksudoku::ViewFlags",
        "flags",
        "symbolsChanged",
        "ksudoku::SymbolTable*",
        "table",
        "valueSelected",
        "value",
        "selectValue",
        "settingsChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'flagsChanged'
        QtMocHelpers::SignalData<void(ksudoku::ViewFlags)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'symbolsChanged'
        QtMocHelpers::SignalData<void(ksudoku::SymbolTable *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'valueSelected'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'selectValue'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'settingsChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KsView, qt_meta_tag_ZN7ksudoku6KsViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ksudoku::KsView::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ksudoku6KsViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ksudoku6KsViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7ksudoku6KsViewE_t>.metaTypes,
    nullptr
} };

void ksudoku::KsView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KsView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->flagsChanged((*reinterpret_cast<std::add_pointer_t<ksudoku::ViewFlags>>(_a[1]))); break;
        case 1: _t->symbolsChanged((*reinterpret_cast<std::add_pointer_t<ksudoku::SymbolTable*>>(_a[1]))); break;
        case 2: _t->valueSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->selectValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->settingsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KsView::*)(ksudoku::ViewFlags )>(_a, &KsView::flagsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KsView::*)(ksudoku::SymbolTable * )>(_a, &KsView::symbolsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KsView::*)(int )>(_a, &KsView::valueSelected, 2))
            return;
    }
}

const QMetaObject *ksudoku::KsView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ksudoku::KsView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ksudoku6KsViewE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ksudoku::KsView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ksudoku::KsView::flagsChanged(ksudoku::ViewFlags _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ksudoku::KsView::symbolsChanged(ksudoku::SymbolTable * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ksudoku::KsView::valueSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
